==> neo4j-cypher-logical-plans-3.3-3.3.1-sources.jar: org/neo4j/cypher/internal/v3_3/logical/plans/FindShortestPaths.scala <==
/*
 * Copyright (c) 2002-2017 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.cypher.internal.v3_3.logical.plans

import org.neo4j.cypher.internal.frontend.v3_3.ast.Expression
import org.neo4j.cypher.internal.ir.v3_3.{CardinalityEstimation, PlannerQuery, ShortestPathPattern}

case class FindShortestPaths(left: LogicalPlan, shortestPath: ShortestPathPattern,
                             predicates: Seq[Expression] = Seq.empty,
                             withFallBack: Boolean = false, disallowSameNode: Boolean = true)
                            (val solved: PlannerQuery with CardinalityEstimation)
  extends LogicalPlan with LazyLogicalPlan {

  val lhs = Some(left)
  def rhs = None

  def availableSymbols = left.availableSymbols ++ shortestPath.availableSymbols
}

==> neo4j-cypher-logical-plans-3.3-3.3.9-sources.jar: org/neo4j/cypher/internal/v3_3/logical/plans/FindShortestPaths.scala <==
/*
 * Copyright (c) 2002-2018 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.cypher.internal.v3_3.logical.plans

import org.neo4j.cypher.internal.frontend.v3_3.ast.Expression
import org.neo4j.cypher.internal.ir.v3_3.{CardinalityEstimation, PlannerQuery, ShortestPathPattern}

case class FindShortestPaths(left: LogicalPlan, shortestPath: ShortestPathPattern,
                             predicates: Seq[Expression] = Seq.empty,
                             withFallBack: Boolean = false, disallowSameNode: Boolean = true)
                            (val solved: PlannerQuery with CardinalityEstimation)
  extends LogicalPlan with LazyLogicalPlan {

  val lhs = Some(left)
  def rhs = None

  val availableSymbols = left.availableSymbols ++ shortestPath.availableSymbols
}
